Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(275)

Unified Diff: runtime/include/dart_api.h

Issue 2275803002: Assign external sizes to external strings and to external typed data created by the VM. (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: sync Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | runtime/vm/clustered_snapshot.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/include/dart_api.h
diff --git a/runtime/include/dart_api.h b/runtime/include/dart_api.h
index 9ea762dc772b95b80135c1c5ee28e332acb1d0ab..3d02adc5312e2c30696626048e5a050bc6467afe 100755
--- a/runtime/include/dart_api.h
+++ b/runtime/include/dart_api.h
@@ -1809,7 +1809,8 @@ DART_EXPORT Dart_Handle Dart_StringStorageSize(Dart_Handle str, intptr_t* size);
*
* \param array External space into which the string data will be
* copied into. This must not move.
* \param length The size in bytes of the provided external space (array).
* \param peer An external pointer to associate with this string.
* \param cback A callback to be called when this string is finalized.
*
@@ -1828,11 +1829,12 @@ DART_EXPORT Dart_Handle Dart_StringStorageSize(Dart_Handle str, intptr_t* size);
* result = Dart_MakeExternalString(str, data, size, NULL, NULL);
*
*/
-DART_EXPORT Dart_Handle Dart_MakeExternalString(Dart_Handle str,
- void* array,
- intptr_t length,
- void* peer,
- Dart_PeerFinalizer cback);
+DART_EXPORT Dart_Handle Dart_MakeExternalString(
+ Dart_Handle str,
+ void* array,
+ intptr_t external_allocation_size,
+ void* peer,
+ Dart_PeerFinalizer cback);
/**
* Retrieves some properties associated with a String.
« no previous file with comments | « no previous file | runtime/vm/clustered_snapshot.cc » ('j') | no next file with comments »
@@ -1809,7 +1809,8 @@ DART_EXPORT Dart_Handle Dart_StringStorageSize(Dart_Handle str, intptr_t* size);
* \param array External space into which the string data will be
* copied into. This must not move.
- * \param length The size in bytes of the provided external space (array).
+ * \param external_allocation_size The size in bytes of the provided external
+ * space (array). Used to inform the garbage collector.
* \param peer An external pointer to associate with this string.
* \param cback A callback to be called when this string is finalized.

Powered by Google App Engine
This is Rietveld 408576698